@@ -1,5 +1,6 @@
 import os
 import sys
+from datetime import datetime
 
 # Do not touch these. They use the local PRAW over the global PRAW.
 sys.path.insert(0, ".")
@@ -7,15 +8,20 @@ sys.path.insert(1, "..")
 
 from praw import __version__
 
-copyright = "2020, Bryce Boe"
+copyright = datetime.today().strftime("%Y, Bryce Boe")
 exclude_patterns = ["_build"]
 extensions = ["sphinx.ext.autodoc", "sphinx.ext.intersphinx"]
 html_static_path = ["_static"]
 html_theme = "sphinx_rtd_theme"
 html_theme_options = {"collapse_navigation": True}
 htmlhelp_basename = "PRAW"
-intersphinx_mapping = {"python": ("https://docs.python.org/3.8", None)}
+intersphinx_mapping = {"python": ("https://docs.python.org", None)}
 master_doc = "index"
+nitpick_ignore = [
+    ("py:class", "IO"),
+    ("py:class", "prawcore.requestor.Requestor"),
+    ("py:class", "praw.models.redditors.PartialRedditor"),
+]
 nitpicky = True
 project = "PRAW"
 pygments_style = "sphinx"
@@ -24,7 +30,6 @@ source_suffix = ".rst"
 suppress_warnings = ["image.nonlocal_uri"]
 version = ".".join(__version__.split(".", 2)[:2])
 
-
 # Use RTD theme locally
 if not os.environ.get("READTHEDOCS"):
     import sphinx_rtd_theme
@@ -47,4 +52,4 @@ def skip(app, what, name, obj, skip, options):
 
 def setup(app):
     app.connect("autodoc-skip-member", skip)
-    app.add_stylesheet("theme_override.css")
+    app.add_css_file("theme_override.css")
